@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2017 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -55,6 +55,11 @@ OptionsTab::OptionsTab(QWidget *parent, Qt::WindowFlags fl)
 }
 
 
+void OptionsTab::resizeEvent(QResizeEvent *event)
+{
+}
+
+
 void OptionsTab::removeSpaceLines()
 {
     QStringList sl;
@@ -62,6 +67,7 @@ void OptionsTab::removeSpaceLines()
     QString t = textEdit->toPlainText();
     sl = t.split("\n");
     t = "";
+
     foreach(QString entry, sl) {
         if (entry.length() == 0) {
             found = true;
@@ -136,6 +142,12 @@ QString OptionsTab::getAndTestUrlString(const QString st)
 
 void OptionsTab::translateTab()
 {
+    setMinimumSize(410, 250);
+
+    // ajust size(hight) to content
+    textEdit->setFixedHeight(textEdit->document()->size().height() + textEdit->contentsMargins().top() * 2);
+
+
     if (parent->programStyleSheet.length() > 0) {
         setStyleSheet(parent->programStyleSheet);
     }
