@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2017 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -116,13 +116,17 @@ void ProgressTab::resizeEvent(QResizeEvent *event)
 
 void ProgressTab::translateTab()
 {
+    setMinimumSize(410, 250);
+
+    // ajust size(hight) to content
+    //     progressSheet->setFixedHeight(progressSheet->document()->size().height() + progressSheet->contentsMargins().top()*2);
     //     int maxRows = 32;//parent->maxConnections;
     if (parent->programStyleSheet.length() > 0) {
         setStyleSheet(parent->programStyleSheet);
     }
 
     l_process->setText(translate(_INPROGRESS) + " " + parent->currentProject);
-    groupBox->setTitle(translate(_INFO));
+    //     groupBox->setTitle(translate(_INFO));
     l_saved->setText(translate(_BYTESSAVED));
     l_time->setText(translate(_TIME));
     l_rate->setText(translate(_TRRATE));
