@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2017 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -38,8 +38,13 @@ StartTab::StartTab(QWidget *parent, Qt::WindowFlags fl)
 }
 
 
+void StartTab::resizeEvent(QResizeEvent *event)
+{
+}
+
 void StartTab::translateTab()
 {
+    setMinimumSize(410, 250);
     QString v;
 
     if (parent->programStyleSheet.length() > 0) {
