@@ -1570,7 +1570,7 @@ void HTTraQt::readSettings(bool global)
     if (global == true) {
         s = new QSettings(QSettings::UserScope, "KarboSoft", "HTTraQt");
 
-        currentWorkDir = s->value("WorkDir", QDir::homePath() + "/My Web Sites").toString();
+        currentWorkDir = s->value(QString("WorkDir"), QString(QDir::homePath() + "/My Web Sites")).toString();
     } else {
         fname = currentWorkDir + "/" + currentProject + "/linprofile.ini";
 
