@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2017 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -36,6 +36,10 @@ class FinalTab: public QWidget, public Ui::FinalTab, public cTranslator
         FinalTab(QWidget *parent = 0, Qt::WindowFlags fl = 0);
     public slots:
         void translateTab(void);
+
+    protected:
+        void resizeEvent(QResizeEvent *event);
+
     private slots:
         void onBrowseLocalWebsite();
         void onViewLog();
