@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2017 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -39,6 +39,9 @@ class OptionsTab: public QWidget, public Ui::OptionsTab, public cTranslator
         void translateTab();
         void updateLastAction();
 
+    protected:
+        void resizeEvent(QResizeEvent *event);
+
     private slots:
         void onSetOptions();
         void onURLList();
