@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2017 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -34,6 +34,9 @@ class StartTab: public QWidget, public Ui::StartTab, public cTranslator
         StartTab(QWidget *parent = 0, Qt::WindowFlags fl = 0);
         void translateTab();
 
+    protected:
+        void resizeEvent(QResizeEvent *event);
+
     private:
         HTTraQt* parent;
 };
