@@ -24,8 +24,8 @@
 #include <htsstrings.h>
 #include "includes/options.h"
 
-
-QMap<QString, OptStruct> cOptions::prOptions;
+// init of static object
+QMap<QString, QVariant> cOptions::prOptions;
 
 
 void cOptions::SetProfile(const QString &variName, float val)
@@ -34,15 +34,27 @@ void cOptions::SetProfile(const QString &variName, float val)
         return;
     }
 
-    OptStruct tmp = prOptions[variName];
+    QVariant tmp = prOptions[variName];
 
-    if (tmp.type != FLOAT) {
+    if (tmp.type() != QMetaType::Float) {
         qDebug() << "Wrong type, setProfile()" << variName << "was expected FLOAT!";
         return;
     }
 
-    tmp.value = val;
-    prOptions[variName] = tmp;
+    //     tmp = val;
+    prOptions[variName] = val;
+}
+
+
+
+void cOptions::SetProfile(const QString &variName, const QVariant &val)
+{
+    if (variName.length() < 1) {
+        return;
+    }
+
+    //     tmp = val;
+    prOptions[variName] = val;
 }
 
 
@@ -52,15 +64,15 @@ void cOptions::SetProfile(const QString &variName, int val)
         return;
     }
 
-    OptStruct tmp = prOptions[variName];
+    QVariant tmp = prOptions[variName];
 
-    if (tmp.type != INTEGER) {
+    if (tmp.type() != QMetaType::Int) {
         qDebug() << "Wrong type, setProfile()" << variName << "was expected INTEGER!";
         return;
     }
 
-    tmp.value = val;
-    prOptions[variName] = tmp;
+    //     tmp.value = val;
+    prOptions[variName] = val;
 }
 
 
@@ -70,15 +82,25 @@ void  cOptions::SetProfile(const QString &variName, const QString &val)
         return;
     }
 
-    OptStruct tmp = prOptions[variName];
+    QVariant tmp = prOptions[variName];
 
-    if (tmp.type != TEXT) {
+    if (tmp.type() != QMetaType::QString) {
         qDebug() << "Wrong type, setProfile()" << variName << "was expected TEXT!";
         return;
     }
 
-    tmp.value = val;
-    prOptions[variName] = tmp;
+    //     tmp.value = val;
+    prOptions[variName] = val;
+}
+
+
+QVariant cOptions::GetProfile(const QString &variName)
+{
+    if (variName.length() < 1) {
+        return -1;
+    }
+
+    return prOptions[variName];
 }
 
 
@@ -88,14 +110,14 @@ void cOptions::GetProfile(const QString &variName, float &val)
         return;
     }
 
-    OptStruct tmp = prOptions[variName];
+    QVariant tmp = prOptions[variName];
 
-    if (tmp.type != FLOAT) {
+    if (tmp.type() != QMetaType::Float) {
         qDebug() << "Wrong type, getProfile()" << variName << "was expected FLOAT!";
         return;
     }
 
-    val = tmp.value.toFloat();
+    val = tmp.toFloat();
 }
 
 
@@ -105,14 +127,14 @@ void cOptions::GetProfile(const QString &variName, int &val)
         return;
     }
 
-    OptStruct tmp = prOptions[variName];
+    QVariant tmp = prOptions[variName];
 
-    if (tmp.type != INTEGER) {
+    if (tmp.type() != QMetaType::Int) {
         qDebug() << "Wrong type, getProfile()" << variName << "was expected INTEGER!";
         return;
     }
 
-    val = tmp.value.toInt();
+    val = tmp.toInt();
 }
 
 
@@ -122,14 +144,14 @@ void cOptions::GetProfile(const QString &variName, QString &val)
         return;
     }
 
-    OptStruct tmp = prOptions[variName];
+    QVariant tmp = prOptions[variName];
 
-    if (tmp.type != TEXT) {
+    if (tmp.type() != QMetaType::QString) {
         qDebug() << "Wrong type, getProfile()" << variName << "was expected TEXT!";
         return;
     }
 
-    val = tmp.value.toString();
+    val = tmp.toString();
 }
 
 
@@ -148,23 +170,23 @@ void cOptions::saveOptions(QSettings *s, bool gl)
         SetProfile("UserID", st);
     }
 
-    for (QMap<QString, OptStruct>::const_iterator iopt = prOptions.constBegin(); iopt != prOptions.constEnd(); ++iopt) {
+    for (QMap<QString, QVariant>::const_iterator iopt = prOptions.constBegin(); iopt != prOptions.constEnd(); ++iopt) {
         if (gl == true) { // do not save as global
             if (iopt.key() == "CurrentUrl" || iopt.key() == "CurrentURLList") { // only in project settings
                 continue;
             }
         }
 
-        if ((*iopt).type == TEXT) {
-            QString v = (*iopt).value.toString();
+        if ((*iopt).type() == QMetaType::QString) {
+            QString v = (*iopt).toString();
             profile_code(v);
 
             s->setValue(iopt.key(), v);
         }
 
-        if ((*iopt).type == FLOAT) {
-            if ((*iopt).value.toFloat() >= 0) {
-                float fTmp = (*iopt).value.toFloat();
+        if ((*iopt).type() == QMetaType::Float) {
+            if ((*iopt).toFloat() >= 0) {
+                float fTmp = (*iopt).toFloat();
                 QString fTxt;
                 fTxt = QString().sprintf("%6.4f", fTmp);
                 //qDebug() << "save" << (*iopt).name << fTxt;
@@ -174,9 +196,9 @@ void cOptions::saveOptions(QSettings *s, bool gl)
             }
         }
 
-        if ((*iopt).type == INTEGER) {
-            if ((*iopt).value.toInt() != -1) {
-                s->setValue(iopt.key(), (*iopt).value.toInt());
+        if ((*iopt).type() == QMetaType::Int) {
+            if ((*iopt).toInt() != -1) {
+                s->setValue(iopt.key(), (*iopt).toInt());
             } else {
                 s->setValue(iopt.key(), "");
             }
@@ -228,20 +250,20 @@ void cOptions::loadOptions(QSettings *s)
     initOptions();
     //     qDebug() << "load";
 
-    for (QMap<QString, OptStruct>::iterator iopt = prOptions.begin(); iopt != prOptions.end(); ++iopt) {
-        if ((*iopt).type == TEXT) {
+    for (QMap<QString, QVariant>::iterator iopt = prOptions.begin(); iopt != prOptions.end(); ++iopt) {
+        if ((*iopt).type() == QMetaType::QString) {
             QString tStr;
-            tStr = s->value(iopt.key(), (*iopt).value).toString();
+            tStr = s->value(iopt.key(), (*iopt).toString()).toString();
             profile_decode(tStr);
-            (*iopt).value = tStr;
+            (*iopt) = tStr;
 
             continue;
         }
 
-        if ((*iopt).type == FLOAT) {
+        if ((*iopt).type() == QMetaType::QString) {
             float tFloat;
             bool iOk;
-            tFloat = s->value(iopt.key(), (*iopt).value).toFloat(&iOk);
+            tFloat = s->value(iopt.key(), (*iopt).toFloat()).toFloat(&iOk);
 
             if (iOk == true) {
                 if (tFloat >= 0) {
@@ -251,21 +273,21 @@ void cOptions::loadOptions(QSettings *s)
                 }
 
                 //qDebug() << "load" << (*iopt).name << tFloat << (qint64)tFloat;
-                (*iopt).value = tFloat; // overwrite the default value if right
+                (*iopt) = tFloat; // overwrite the default value if right
             } else {
-                (*iopt).value = -1.0;
+                (*iopt) = -1.0;
             }
 
             continue;
         }
 
-        if ((*iopt).type == INTEGER) {
+        if ((*iopt).type() == QMetaType::Int) {
             int tInt;
             bool iOk;
-            tInt = s->value(iopt.key(), (*iopt).value).toInt(&iOk);
+            tInt = s->value(iopt.key(), (*iopt).toInt()).toInt(&iOk);
 
             if (iOk == true) {
-                (*iopt).value = tInt; // overwrite the default value if right
+                (*iopt) = tInt; // overwrite the default value if right
             }
 
             continue;
@@ -1040,211 +1062,79 @@ QString cOptions::cmdArgumentsOptions(int num)
 void cOptions::initOptions()
 {
     //     QMap<QString, OptStruct> m;
-    prOptions[ "Near" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "ParseAll" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "Test" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "HTMLFirst" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "Dos" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "ISO9660" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "NoErrorPages" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "NoExternalPages" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "NoPwdInPages" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "NoQueryStrings" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "NoPurgeOldFiles" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "Build" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "WildCardFilters" ] = (OptStruct) {
-        TEXT, "+*.png +*.gif +*.jpg +*.css +*.js -ad.doubleclick.net/*"
-    };
-    prOptions[ "Depth" ] = (OptStruct) {
-        INTEGER, -1
-    };
-    prOptions[ "ExtDepth" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "CurrentAction" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "MaxHtml" ] = (OptStruct) {
-        FLOAT, -1
-    };
-    prOptions[ "MaxOther" ] = (OptStruct) {
-        FLOAT, -1
-    };
-    prOptions[ "MaxAll" ] = (OptStruct) {
-        FLOAT, -1
-    };
-    prOptions[ "MaxWait" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "MaxTime" ] = (OptStruct) {
-        INTEGER, -1
-    };
-    prOptions[ "MaxRate" ] = (OptStruct) {
-        FLOAT, -1
-    };
-    prOptions[ "MaxConn" ] = (OptStruct) {
-        INTEGER, -1
-    };
-    prOptions[ "MaxLinks" ] = (OptStruct) {
-        INTEGER, -1
-    };
-    prOptions[ "Proxy" ] = (OptStruct) {
-        TEXT, ""
-    };
-    prOptions[ "CurrentUrl" ] = (OptStruct) {
-        TEXT, ""
-    };
-    prOptions[ "CurrentURLList" ] = (OptStruct) {
-        TEXT, ""
-    };
-    prOptions[ "Category" ] = (OptStruct) {
-        TEXT, ""
-    };
-    prOptions[ "BuildString" ] = (OptStruct) {
-        TEXT, "%h%p/%n%q.%t"
-    };
-    prOptions[ "UseHTTPProxyForFTP" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "PrimaryScan" ] = (OptStruct) {
-        INTEGER, 4
-    };
-    prOptions[ "Debug" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "UserID" ] = (OptStruct) {
-        TEXT, "Mozilla/5.0 (X11; U; Linux i686; I; rv:17.0.1) Gecko/20100101 Firefox/17.0.1"
-    };
-    prOptions[ "BrowserName" ] = (OptStruct) {
-        TEXT, "Firefox"
-    };
-    prOptions[ "BrowserID" ] = (OptStruct) {
-        TEXT, "Mozilla/5.0 (%s; rv:17.0.1) Gecko/20100101 Firefox/17.0.1"
-    };
-    prOptions[ "osID" ] = (OptStruct) {
-        TEXT, "X11; U; Linux i686; I"
-    };
-    prOptions[ "Travel" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "GlobalTravel" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "RewriteLinks" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "Footer" ] = (OptStruct) {
-        TEXT, "<!-- Mirrored from %s%s by HTTraQt Website Copier/1.x [Karbofos 2012-2017] %s -->"
-    };
-    prOptions[ "Cache" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "TimeOut" ] = (OptStruct) {
-        INTEGER, -1
-    };
-    prOptions[ "Sockets" ] = (OptStruct) {
-        INTEGER, 8
-    };
-    prOptions[ "Retry" ] = (OptStruct) {
-        INTEGER, -1
-    };
-    prOptions[ "KeepAlive" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "RemoveTimeout" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "RemoveRateout" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "RateOut" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "StoreAllInCache" ] = (OptStruct) {
-        INTEGER, 0
-    };
+    prOptions[ "Near" ] = 1;
+    prOptions[ "ParseAll" ] = 1;
+    prOptions[ "Test" ] = 0;
+    prOptions[ "HTMLFirst" ] = 0;
+    prOptions[ "Dos" ] = 0;
+    prOptions[ "ISO9660" ] = 0;
+    prOptions[ "NoErrorPages" ] = 0;
+    prOptions[ "NoExternalPages" ] = 1;
+    prOptions[ "NoPwdInPages" ] = 0;
+    prOptions[ "NoQueryStrings" ] = 1;
+    prOptions[ "NoPurgeOldFiles" ] = 0;
+    prOptions[ "Build" ] = 0;
+    prOptions[ "WildCardFilters" ] = "+*.png +*.gif +*.jpg +*.css +*.js -ad.doubleclick.net/*";
+    prOptions[ "Depth" ] = -1;
+    prOptions[ "ExtDepth" ] = 0;
+    prOptions[ "CurrentAction" ] = 0;
+    prOptions[ "MaxHtml" ] = -1.0;
+    prOptions[ "MaxOther" ] = -1.0;
+    prOptions[ "MaxAll" ] = -1.0;
+    prOptions[ "MaxWait" ] = 0;
+    prOptions[ "MaxTime" ] = -1;
+    prOptions[ "MaxRate" ] = -1.0;
+    prOptions[ "MaxConn" ] = -1;
+    prOptions[ "MaxLinks" ] = -1;
+    prOptions[ "Proxy" ] = "";
+    prOptions[ "CurrentUrl" ] = "";
+    prOptions[ "CurrentURLList" ] = "";
+    prOptions[ "Category" ] = "";
+    prOptions[ "BuildString" ] = "%h%p/%n%q.%t";
+    prOptions[ "UseHTTPProxyForFTP" ] = 0;
+    prOptions[ "PrimaryScan" ] = 4;
+    prOptions[ "Debug" ] = 0;
+    prOptions[ "UserID" ] = "Mozilla/5.0 (X11; U; Linux i686; I; rv:17.0.1) Gecko/20100101 Firefox/17.0.1";
+    prOptions[ "BrowserName" ] = "Firefox";
+    prOptions[ "BrowserID" ] = "Mozilla/5.0 (%s; rv:17.0.1) Gecko/20100101 Firefox/17.0.1";
+    prOptions[ "osID" ] = "X11; U; Linux i686; I";
+    prOptions[ "Travel" ] = 1;
+    prOptions[ "GlobalTravel" ] = 0;
+    prOptions[ "RewriteLinks" ] = 0;
+    prOptions[ "Footer" ] = "<!-- Mirrored from %s%s by HTTraQt Website Copier/1.x [Karbofos 2012-2017] %s -->";
+    prOptions[ "Cache" ] = 1;
+    prOptions[ "TimeOut" ] = -1;
+    prOptions[ "Sockets" ] = 8;
+    prOptions[ "Retry" ] = -1;
+    prOptions[ "KeepAlive" ] = 1;
+    prOptions[ "RemoveTimeout" ] = 0;
+    prOptions[ "RemoveRateout" ] = 0;
+    prOptions[ "RateOut" ] = 0;
+    prOptions[ "StoreAllInCache" ] = 0;
 
     for (int j = 1; j <= 8; ++j) {
         QString n;
         n = "MIMEDefsMime" + QString::number(j);
-        prOptions[ n ] = (OptStruct) {
-            TEXT, ""
-        };
+        prOptions[ n ] = "";
         n = "MIMEDefsExt" + QString::number(j);
-        prOptions[ n ] = (OptStruct) {
-            TEXT, ""
-        };
+        prOptions[ n ] = "";
     }
 
-    prOptions[ "NoRecatch" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "Log" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "Index" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "BuildTopIndex" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "WordIndex" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "LogType" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "URLHack" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "Cookies" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "UpdateHack" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "ParseJava" ] = (OptStruct) {
-        INTEGER, 1
-    };
-    prOptions[ "TolerantRequests" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "HTTP10" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "CheckType" ] = (OptStruct) {
-        INTEGER, 0
-    };
-    prOptions[ "FollowRobotsTxt" ] = (OptStruct) {
-        INTEGER, 2
-    };
-    prOptions[ "ProxyPort" ] = (OptStruct) {
-        INTEGER, 21
-    };
+    prOptions[ "NoRecatch" ] = 0;
+    prOptions[ "Log" ] = 0;
+    prOptions[ "Index" ] = 1;
+    prOptions[ "BuildTopIndex" ] = 1;
+    prOptions[ "WordIndex" ] = 1;
+    prOptions[ "LogType" ] = 0;
+    prOptions[ "URLHack" ] = 1;
+    prOptions[ "Cookies" ] = 1;
+    prOptions[ "UpdateHack" ] = 1;
+    prOptions[ "ParseJava" ] = 1;
+    prOptions[ "TolerantRequests" ] = 0;
+    prOptions[ "HTTP10" ] = 0;
+    prOptions[ "CheckType" ] = 0;
+    prOptions[ "FollowRobotsTxt" ] = 2;
+    prOptions[ "ProxyPort" ] = 21;
 }
 
 
