@@ -1,6 +1,6 @@
 /***************************************************************************
  * C++ Implementation:                                                     *
- * Copyright (C) 2012-2015 by Eduard Kalinowski                            *
+ * Copyright (C) 2012-2017 by Eduard Kalinowski                            *
  * Germany, Lower Saxony, Hanover                                          *
  * eduard_kalinowski@yahoo.de                                              *
  *                                                                         *
@@ -677,7 +677,7 @@ QString cTranslator::convertString(const QString &s)
 }
 
 
-QString cTranslator::translate( int id )
+const QString cTranslator::translate( int id )
 {
     QString m;
 
